.. _bluegraph_core_analyse_ref:

`bluegraph.core.analyse` package
--------------------------------

Reference page for the `bluegraph.core.analyse` package.


Graph metrics
^^^^^^^^^^^^^

.. automodule:: bluegraph.core.analyse.metrics
	:members:


Path search
^^^^^^^^^^^^^

.. automodule:: bluegraph.core.analyse.paths
	:members:


Community Detection
^^^^^^^^^^^^^^^^^^^^

.. automodule:: bluegraph.core.analyse.communities
	:members: